I2CmsgFlags enum
I2C native i2c_msg flags from <linux/i2c.h> - converted only to lower case
camel case looks a little strange
Values
- i2c_m_ten → const I2CmsgFlags
- i2c_m_rd → const I2CmsgFlags
- i2c_m_stop → const I2CmsgFlags
- i2c_m_nostart → const I2CmsgFlags
- i2c_m_rev_dir_addr → const I2CmsgFlags
- i2c_m_ignore_nak → const I2CmsgFlags
- i2c_m_no_rd_ack → const I2CmsgFlags
- i2c_m_recv_len → const I2CmsgFlags
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
I2CmsgFlags> - A constant List of the values in this enum, in order of their declaration.