NanoHatHub class
- Inheritance
-
- Object
- IsolateAPI
- NanoHatHub
- Implemented types
Constructors
- NanoHatHub([int i2cBus = 0])
- NanoHatHub.isolate(I2C i2c)
Properties
Methods
-
analogRead(
int pin) → int -
Reads an analog value from a given
pin.inherited -
analogWrite(
int pin, int value) → void -
Writes an analog
valueto apin.inherited -
autoWait(
) → void -
Ensures that a delay of at last
delayms go by.inherited -
digitalRead(
int pin) → DigitalValue -
Reads a DigitalValue from a given
pin.inherited -
digitalWrite(
int pin, DigitalValue value) → void -
Writes a digital
valueto a givenpin.inherited -
fromJson(
String json) → IsolateAPI -
getFirmwareVersion(
) → String -
Returns the firmware of the hat.
inherited
-
getHandle(
) → int -
isIsolate(
) → bool -
inherited
-
ledBarInit(
int pin) → void - Initialize the LED bar.
-
ledBarInitExt(
int pin, int chipset, int ledNumber) → void - Initializes the LED bar.
-
ledBarRelease(
int pin) → void - Releases the LED bar.
-
ledBarShow(
int pin, int highBits, int lowBits) → void - Shows the LED bar.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pinMode(
int pin, PinMode mode) → void -
Sets the pin
modefor apin.inherited -
readI2Cblock(
int len) → List< int> -
Reads a byte array from the I2C bus.
inherited
-
readUltrasonic(
int pin) → int - Reads a value from the Ultrasonic Ranger in the range form range 5-300cm.
-
servoAttach(
int pin) → void -
Attaches the servo to
pin. -
servoDetach(
int pin) → void -
Detaches the servo from
pin. -
servoWrite(
int pin, int position) → void -
Steers the position of the servo
at
pintoposition. -
setAutoWait(
bool flag) → void -
Enable or disables the auto wait.
inherited
-
setHandle(
int handle) → void -
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
writeI2Cblock(
List< int> data) → void -
Writes a byte array to the I2C bus.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited